==> bforum1.01Beta-1-1.00.0055.tar.gz: bforum1.01Beta-1/b2a.pl <==
#!/usr/bin/perl
#==========================================================================#
#  B.Forum b2a.pl Ver.1.01                                               #
#  2002/6/26                                                             #
#  Hiroaki,Sakuma (sakuma@beetas.org)                                    #
#                                                                          #
# Υץꥱϥץ󥽡Ǥ.                          #
# ̵ǻѤ뤳ȤǤޤ.                                            #
# ʤ, ܺ٤ʻѾ/ǿˤĤƤϲȤ.           #
# http://www.beetas.org/                                                   #
#                                                                          #
# ------------------------------------------------------------------------ #
# Copyright 2002 Hiroaki,Sakuma All Rights Reserved.                       #
# Copyright 2002 BEETAS.org All Rights Reserved.                           #
#                                                                          #
#==========================================================================#
package b2a;
$version = '1.01-1';
$revision = '1.01.0007';
$rcfile = '.bforumrc';

unshift (@INC,'.');

require './Bforum.pm';

&main;

sub main {

	$start = (times)[0];

	&decode;

	$in{'h'} ||= $in{'help'};
	$in{'d'} ||= $in{'delete'};
	$in{'v'} ||= $in{'version'};

	$account = 0;
	$dir = 0;
	$files = 0;
	$compress = 0;

	&Bforum::setting(\%SET,"./$rcfile","$ENV{'HOME'}/$rcfile");
	&Bforum::_path($SET{'USER_DIR'});

	if ($in{'v'}) {
		&version;
		exit;
	} elsif ($in{'h'} || !%in || (!$in{'b'} && !$in{'id'})) {
		&version;
		&usage;
	}

	&version;
	if ($in{'r'}) {
		&reflexive("$SET{'USER_DIR'}/$in{'id'}");
	} else {
		&init;
	}
	&finish;

}

sub usage {
	$print = <<"END";
Ȥ:

ޤ, bforum.cgiBForum.pmΤǥ쥯ȥذưޤ.

\$ ./b2a.pl [-ץ] оݥ

-r            ƵŪ˥ǥ쥯ȥ򸡺, оݰʲΥǥ쥯ȥˤ
              ƤΥȤоݤˤޤ.
-d            ֲեϺޤ.
-b            BF.*եоݤˤޤ.
--charset="." åʸɤꤷޤ. ɸeucǤ.
              ǤΤ'euc','sjis','jis'Ǥ.

:

\$ cd cgi-bin
\$ ./b2a.pl -rd Account

\[Win32\]
C:\\web\\cgi-bin\\bforum> b2a.pl --charset=sjis -r Account
END
	print code($print);
	exit;
}

sub version {
	printf ("%1s%-74s%1s\n","#",("=" x 74),"#");
	printf code("%1s%-74s%1s\n","#","  B.Forum b2a.pl Ver.$version($revision)","#");
	printf code("%1s%-74s%1s\n","#","  Hiroaki,Sakuma (sakuma\@beetas.org)","#");
	printf ("%1s%-74s%1s\n","#"," ","#");
	printf ("%1s%-74s%1s\n","#"," This is free software.","#");
	printf ("%1s%-74s%1s\n","#"," You can use of free.","#");
	printf ("%1s%-74s%1s\n","#"," See the our webpage for more details and news.","#");
	printf ("%1s%-74s%1s\n","#"," http://www.beetas.org/","#");
	printf ("%1s%-74s%1s\n","#"," ","#");
	printf ("%1s %-72s %1s\n","#",("-" x 72),"#");
	printf ("%1s%-74s%1s\n","#"," Copyright 2002 Hiroaki,Sakuma All Rights Reserved.","#");
	printf ("%1s%-74s%1s\n","#"," Copyright 2002 BEETAS.org All Rights Reserved.","#");
	printf ("%1s%-74s%1s\n","#"," ","#");
	printf ("%1s%-74s%1s\n","#",("=" x 74),"#");
	print "\n";
}

sub finish {
	print "\n";
	printf ("%1s%-74s%1s\n","#",("=" x 74),"#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Time",sprintf("%.2f",((times)[0] - $start)),"sec.","#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Account","$account",undef,"#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Directory","$dir",undef,"#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Files","$files",undef,"#");
	if ($compress) {
		printf code("%1s%-20s%30s  %-22s%1s\n","#","  Compress","Yes($compress/$account)",undef,"#");
	} else {
		printf code("%1s%-20s%30s  %-22s%1s\n","#","  Compress","No",undef,"#");
	}

	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Size(Files)",&comma($f_size),"Byte","#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Size(Archives)",&comma($a_size),"Byte","#");
	if ($SET{'COMPRESS_DO'} ne 'N' && $f_size) {
		printf code("%1s%-20s%30s  %-22s%1s\n","#","  Compress rate",int(100 * $a_size / $f_size),"%","#");
	}
	printf ("%1s%-74s%1s\n","#",("=" x 74),"#");
	exit;
}

sub comma {
	my ($tmp1);
	my (@tmp2);
	$tmp1 = $_[0];
	if (!$tmp1) { return "0"; }
	while ($tmp1) {
		unshift (@tmp2,substr($tmp1,-3,3,undef));
	}
	return join(',',@tmp2);
}

sub code {
	undef $tmp2;

	@tmp2 = @_;

	if ($in{'charset'}) {
		if (!$init{'code'}) {
			if ($SET{'NKF'}) {
				eval("use $SET{'NKF'}");
			} elsif ($SET{'JCODE'}) {
				require $SET{'JCODE'} || &error;
			}
			$init{'code'} = 1;
		}

		if ($init{'code'}) {

			$tmp1 = $in{'charset'};

			foreach (@tmp2) {
				if ($_ =~ /\w/) {
					if ($SET{'NKF'}) {
						$$tmp1 = NKF::nkf("--$tmp1",$_);
					} elsif ($SET{'JCODE'}) {
						jcode::convert(\$_,$tmp1,'euc','z');
					}
				}
			}

		}

	}

	return @tmp2;

}

sub reflexive {
	local ($open) = $_[0];

	local (@files,$path);
	opendir (DIR,$open);
	@files = readdir(DIR);
	closedir (DIR);
	foreach $path (@files) {
		if ($path eq '.' || $path eq '..') { next; }
		if ($path eq 'index') {
			$in{'id'} = $open;
			$in{'id'} =~ s/^$SET{'USER_DIR'}\///g;
			&init;
		}
		$path = "$open/$path";
		if (-d $path) { &reflexive($path); }
	}
}

sub init {

	&Bforum::setting(\%SET,"$SET{'USER_DIR'}/$in{'id'}/$rcfile");
	&Bforum::_path($SET{'USER_DIR'});

	if (-f "$SET{'USER_DIR'}/$in{'id'}/index" || $in{'b'}) {
		printf ("%-76s","=>$in{'id'}");
		if ($SET{'ARCHIVE_DO'} ne 'N') {
#			eval ("use $SET{'ARCHIVE'}");
			eval ("use Archive::Tar");
			if ($@) { return; }
		} else {
			return;
		}

		if ($tmp1 = &mkarchive("$SET{'USER_DIR'}/$in{'id'}")) {
			print "Error:$tmp1\n";
		} else {
			print ("\b" x 76);
			printf ("=>$in{'id'}\[Complete\]%-" . (76 -(length($in{'id'})) - 12) . "s\n",undef);
			if ($SET{'COMPRESS_DO'} ne 'N') {
				$compress++;
			}
		}

	}

}

sub mkarchive {

	my ($tmp1,$tmp2);
	my (@tmp);

	if(-d $_[0] && $in{'b'}) {
		$account++;
		&archive($_[0],undef,'BF');
	} elsif (-f "$_[0]/index") {
		$account++;
		$tmp1 = @tmp = &Bforum::_open('file',"$_[0]/index");
		undef $tmp2;
		foreach (@tmp) {
			chomp $_;
			if(-d "$_[0]/$_") { &archive($_[0],"/$_","$_"); }

			$tmp2++;
			print ("\b" x 76);
			printf ("=>$in{'id'}\[%s\]#%-" . (76 -(length("$in{'id'}$_")) - 10) . "s#%3d\%", "$_",('=' x (int($tmp2 * (76 - (length("$in{'id'}$_")) - 10) / $tmp1))),(int(100 * $tmp2 / $tmp1)));
		}
	}


	return;
}

sub archive {
	my ($tmp1,$tmp2,$tmp3,$tmp4,$tmp5);
	my (@tmp);

	opendir (DIR,"$_[0]$_[1]");
	$tmp1 = @tmp = readdir(DIR);
	undef $tmp4;
	foreach (@tmp) {

		if ($_ eq '.' || $_ eq '..') { next; }

		if ($_[2] eq 'BF') {
			if ($_ !~ /^BF\..+$/) { next; }
			print ("\b" x 76);
			printf ("=>$in{'id'}\[%s\]#%-" . (76 -(length("$in{'id'}$_")) - 10) . "s#%3d\%", "$_",('=' x (int($tmp4 * (76 - (length("$in{'id'}$_")) - 10) / $tmp1))),(int(100 * $tmp4 / $tmp1)));
		}

		if (-f "$_[0]$_[1]/$_" && $_ !~ /\.bfa$/) {

			$f_size += (-s "$_[0]$_[1]/$_");

			$tmp4++;

			open (FILE,"$_[0]$_[1]/$_");
			binmode (FILE);
			$tmp3 = join('',<FILE>);
			close (FILE);
			if ($in{'d'}) { unlink("$_[0]$_[1]/$_"); }

			$tmp2 = Archive::Tar->new();
			if ($_ =~ /^(list)$/o) {
				if (-f ("$_[0]/$_[2].0.bfa")) { $tmp2->read(("$_[0]/$_[2].0.bfa"),1) }
				$tmp2->remove($_);
				$tmp2->add_data($_,$tmp3);
				if ($SET{'COMPRESS_DO'} ne 'N') {
					&Bforum::_compress(("$_[0]/$_[2].0.bfa"),$tmp2->write());
				} else {
					$tmp2->write(("$_[0]/$_[2].0.bfa"));
				}
			} elsif ($_ =~ /^\d+$/o) {
				if (-f ("$_[0]/$_[2]." . int ($_ / 10) . ".bfa")) { $tmp2->read(("$_[0]/$_[2]." . int ($_ / 10) . ".bfa"),1) }
				$tmp2->remove($_);
				$tmp2->add_data($_,$tmp3);
				if ($SET{'COMPRESS_DO'} ne 'N') {
					&Bforum::_compress(("$_[0]/$_[2]." . int ($_ / 10) . ".bfa"),$tmp2->write());
				} else {
					$tmp2->write(("$_[0]/$_[2]." . int ($_ / 10) . ".bfa"));
				}
			} else {
				if (-f "$_[0]/$_[2]") { $tmp2->read("$_[0]/$_[2]",1) }
				$tmp2->remove($_);
				$tmp2->add_data($_,$tmp3);
				if ($SET{'COMPRESS_DO'} ne 'N') {
					&Bforum::_compress("$_[0]/$_[2].bfa",$tmp2->write());
				} else {
					$tmp2->write("$_[0]/$_[2].bfa");
				}
			}
			undef $tmp2;
		}
	}

	$dir++;
	$files += $tmp4;

	closedir (DIR);

	$a_size += (-s "$_[0]/$_[2]");

	if ($in{'d'} && "$_[0]$_[1]" ne "$SET{'USER_DIR'}/$in{'id'}") {
		rmdir("$_[0]$_[1]") || print "\nrmdir $_[0]$_[1] : $!\n";
	}

	return;
}

sub decode {
	my ($buffer);
	if ($ENV{'REQUEST_METHOD'} eq "POST") {
		read(STDIN, $buffer, $ENV{'CONTENT_LENGTH'});
	} else { $buffer = $ENV{'QUERY_STRING'}; }
	if (!$buffer) { $buffer = $ARGV[0]; }
	foreach (@ARGV) {
		if ($_ =~ /--(.*)=(.*)/) {
			$in{$1} = $2;
		} elsif ($_ =~ /--(.*)/) {
			$in{$1} = 1;
		} elsif ($_ =~ /-(.*)/) {
			foreach (split(//,$1)) {
				$in{$_} = 1;
			}
		} else {
			$in{'id'} = $_;
		}
	}

	undef @_;
}

sub error {
	print "\nError:" . (caller)[2] . '@' . (caller)[1];
	undef @_;
	exit;
}

==> bforum1.02Beta-1-1.02.0065.tar.gz: bforum1.02Beta-1/b2a.pl <==
#!/usr/bin/perl
#==========================================================================#
#  B.Forum b2a.pl Ver.1.01                                               #
#  Encode = EUC                                                          #
#  Sakuma,Hiroaki( sakuma@beetas.org )                                   #
#  BEETAS.org( info@beetas.org )                                         #
#                                                                          #
# Υץꥱϥץ󥽡Ǥ.                          #
# ̵ǻѤ뤳ȤǤޤ.                                            #
# ʤ, ܺ٤ʻѾ/ǿˤĤƤϲȤ.           #
# http://www.beetas.org/                                                   #
#                                                                          #
# ------------------------------------------------------------------------ #
# Copyright 2002-2004 Sakuma,Hiroaki All Rights Reserved.                  #
# Copyright 2002-2004 BEETAS.org All Rights Reserved.                      #
#                                                                          #
#==========================================================================#
package b2a;
$version = '1.01-5';
$revision = '1.01.0011';
$rcfile = '.bforumrc';

unshift (@INC,'.');

use Bforum;

&main;

sub main {

	$start = (times)[0];

	&decode;

	$in{'h'} ||= $in{'help'};
	$in{'d'} ||= $in{'delete'};
	$in{'v'} ||= $in{'version'};

	$account = 0;
	$dir = 0;
	$files = 0;
	$compress = 0;

	&Bforum::setting(\%SET,"./$rcfile","$ENV{'HOME'}/$rcfile");
	&Bforum::_path($SET{'USER_DIR'});

	if ($in{'v'}) {
		&version;
		exit;
	} elsif ($in{'h'} || !%in) {
		&version;
		&usage;
	}

	&version;
	if ($in{'id'}) {
		if ($in{'r'}) {
			&reflexive("$SET{'USER_DIR'}/$in{'id'}");
		} else {
			&init;
		}
	} else {
		if ($in{'b'}) {
			&init;
		} else {
			&reflexive("$SET{'USER_DIR'}");
		}
	}
	&finish;

}

sub usage {
	$print = <<"END";
Ȥ:

ޤ, bforum.cgiBforum.pmΤǥ쥯ȥذưޤ.

\$ ./b2a.pl [-ץ] [оݥ]

-r            ƵŪ˥ǥ쥯ȥ򸡺, оݰʲΥǥ쥯ȥˤ
              ƤΥȤоݤˤޤ.
-d            ֲեϺޤ.
-b            BF.*եоݤˤޤ.
--charset="." åʸɤꤷޤ. ɸeucǤ.
              ǤΤ'euc','sjis','jis'Ǥ.

 *** оݥȤάƤΥȤоݤˤʤޤ. ***

:

\$ cd cgi-bin
\$ ./b2a.pl -rd Account

\[Win32\]
C:\\web\\cgi-bin\\bforum> b2a.pl --charset=sjis -r Account
END
	print code($print);
	exit;
}

sub version {
	printf ("%1s%-74s%1s\n","#",("=" x 74),"#");
	printf code("%1s%-74s%1s\n","#","  B.Forum b2a.pl Ver.$version($revision)","#");
	printf code("%1s%-74s%1s\n","#","  Sakuma,Hiroaki (sakuma\@beetas.org)","#");
	printf code("%1s%-74s%1s\n","#","  BEETAS.org (info\@beetas.org)","#");
	printf ("%1s%-74s%1s\n","#"," ","#");
	printf ("%1s%-74s%1s\n","#"," This is free software.","#");
	printf ("%1s%-74s%1s\n","#"," You can use of free.","#");
	printf ("%1s%-74s%1s\n","#"," See the our webpage for more details and news.","#");
	printf ("%1s%-74s%1s\n","#"," http://www.beetas.org/","#");
	printf ("%1s%-74s%1s\n","#"," ","#");
	printf ("%1s %-72s %1s\n","#",("-" x 72),"#");
	printf ("%1s%-74s%1s\n","#"," Copyright 2002-2004 Sakuma,Hiroaki All Rights Reserved.","#");
	printf ("%1s%-74s%1s\n","#"," Copyright 2002-2004 BEETAS.org All Rights Reserved.","#");
	printf ("%1s%-74s%1s\n","#"," ","#");
	printf ("%1s%-74s%1s\n","#",("=" x 74),"#");
	print "\n";
}

sub finish {
	print "\n";
	printf ("%1s%-74s%1s\n","#",("=" x 74),"#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Time",sprintf("%.2f",((times)[0] - $start)),"sec.","#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Account","$account",undef,"#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Directory","$dir",undef,"#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Files","$files",undef,"#");
	if ($compress) {
		printf code("%1s%-20s%30s  %-22s%1s\n","#","  Compress","Yes($compress/$account)",undef,"#");
	} else {
		printf code("%1s%-20s%30s  %-22s%1s\n","#","  Compress","No",undef,"#");
	}

	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Size(Files)",&comma($f_size),"Byte","#");
	printf code("%1s%-20s%30s  %-22s%1s\n","#","  Size(Archives)",&comma($a_size),"Byte","#");
	if ($SET{'COMPRESS_DO'} ne 'N' && $f_size) {
		printf code("%1s%-20s%30s  %-22s%1s\n","#","  Compress rate",int(100 * $a_size / $f_size),"%","#");
	}
	printf ("%1s%-74s%1s\n","#",("=" x 74),"#");
	exit;
}

sub comma {
	my ($tmp1);
	my (@tmp2);
	$tmp1 = $_[0];
	if (!$tmp1) { return "0"; }
	while ($tmp1) {
		unshift (@tmp2,substr($tmp1,-3,3,undef));
	}
	return join(',',@tmp2);
}

sub code {
	undef $tmp2;

	@tmp2 = @_;

	if ($in{'charset'}) {
		if (!$init{'code'}) {
			if ($SET{'NKF'}) {
				eval("use $SET{'NKF'}");
			} elsif ($SET{'JCODE'}) {
				require $SET{'JCODE'} || &error;
			}
			$init{'code'} = 1;
		}

		if ($init{'code'}) {

			$tmp1 = $in{'charset'};

			foreach (@tmp2) {
				if ($_ =~ /\w/) {
					if ($SET{'NKF'}) {
						$$tmp1 = NKF::nkf("--$tmp1",$_);
					} elsif ($SET{'JCODE'}) {
						jcode::convert(\$_,$tmp1,'euc','z');
					}
				}
			}

		}

	}

	return @tmp2;

}

sub reflexive {
	local ($open) = $_[0];

	local (@files,$path);
	opendir (DIR,$open);
	@files = readdir(DIR);
	closedir (DIR);
	foreach $path (@files) {
		if ($path eq '.' || $path eq '..') { next; }
		if ($path eq 'index') {
			$in{'id'} = $open;
			$in{'id'} =~ s/^$SET{'USER_DIR'}\///g;
			&init;
		}
		$path = "$open/$path";
		if (-d $path) { &reflexive($path); }
	}
}

sub init {

	&Bforum::setting(\%SET,"$SET{'USER_DIR'}/$in{'id'}/$rcfile");
	&Bforum::_path($SET{'USER_DIR'});

	if (-f "$SET{'USER_DIR'}/$in{'id'}/index" || $in{'b'}) {
		printf ("%-76s","=>$in{'id'}");
		if ($SET{'ARCHIVE_DO'} ne 'N') {
#			eval ("use $SET{'ARCHIVE'}");
			eval ("use Archive::Tar");
			if ($@) {
				print ("\b" x 76);
				printf ("=>$in{'id'}\[Skip\]%-" . (76 -(length($in{'id'})) - 8) . "s\n",undef);
				return;
			}
		} else {
			print ("\b" x 76);
			printf ("=>$in{'id'}\[Skip\]%-" . (76 -(length($in{'id'})) - 8) . "s\n",undef);
			return;
		}

		if ($tmp1 = &mkarchive("$SET{'USER_DIR'}/$in{'id'}")) {
			print "Error:$tmp1\n";
		} else {
			print ("\b" x 76);
			printf ("=>$in{'id'}\[Complete\]%-" . (76 -(length($in{'id'})) - 12) . "s\n",undef);
			if ($SET{'COMPRESS_DO'} ne 'N') {
				$compress++;
			}
		}

	}

}

sub mkarchive {

	my ($tmp1,$tmp2);
	my (@tmp);

	if(-d $_[0] && $in{'b'}) {
		$account++;
		&archive($_[0],undef,'BF');
	} elsif (-f "$_[0]/index") {
		$account++;
		$tmp1 = @tmp = &Bforum::_open('file',"$_[0]/index");
		undef $tmp2;
		foreach (@tmp) {
			chomp $_;
			if(-d "$_[0]/$_") { &archive($_[0],"/$_","$_"); }

			$tmp2++;
			print ("\b" x 76);
			printf ("=>$in{'id'}\[%s\]#%-" . (76 -(length("$in{'id'}$_")) - 10) . "s#%3d\%", "$_",('=' x (int($tmp2 * (76 - (length("$in{'id'}$_")) - 10) / $tmp1))),(int(100 * $tmp2 / $tmp1)));
		}
	}


	return;
}

sub archive {
	my ($tmp1,$tmp2,$tmp3,$tmp4,$tmp5);
	my (@tmp);

	opendir (DIR,"$_[0]$_[1]");
	$tmp1 = @tmp = readdir(DIR);
	undef $tmp4;
	foreach (@tmp) {

		if ($_ eq '.' || $_ eq '..') { next; }

		if ($_[2] eq 'BF') {
			if ($_ !~ /^BF\..+$/) { next; }
			print ("\b" x 76);
			printf ("=>$in{'id'}\[%s\]#%-" . (76 -(length("$in{'id'}$_")) - 10) . "s#%3d\%", "$_",('=' x (int($tmp4 * (76 - (length("$in{'id'}$_")) - 10) / $tmp1))),(int(100 * $tmp4 / $tmp1)));
		}

		if (-f "$_[0]$_[1]/$_" && $_ !~ /\.bfa$/) {

			$f_size += (-s "$_[0]$_[1]/$_");

			$tmp4++;

			open (FILE,"$_[0]$_[1]/$_");
			binmode (FILE);
			$tmp3 = join('',<FILE>);
			close (FILE);
			if ($in{'d'}) { unlink("$_[0]$_[1]/$_"); }

			$tmp2 = Archive::Tar->new();
			if ($_ =~ /^(list)$/o) {
				if (-f ("$_[0]/$_[2].0.bfa")) { $tmp2->read(("$_[0]/$_[2].0.bfa"),1) }
				$tmp2->remove($_);
				$tmp2->add_data($_,$tmp3);
				if ($SET{'COMPRESS_DO'} ne 'N') {
					&Bforum::_compress(("$_[0]/$_[2].0.bfa"),$tmp2->write());
				} else {
					$tmp2->write(("$_[0]/$_[2].0.bfa"));
				}
			} elsif ($_ =~ /^\d+$/o) {
				if (-f ("$_[0]/$_[2]." . int ($_ / 10) . ".bfa")) { $tmp2->read(("$_[0]/$_[2]." . int ($_ / 10) . ".bfa"),1) }
				$tmp2->remove($_);
				$tmp2->add_data($_,$tmp3);
				if ($SET{'COMPRESS_DO'} ne 'N') {
					&Bforum::_compress(("$_[0]/$_[2]." . int ($_ / 10) . ".bfa"),$tmp2->write());
				} else {
					$tmp2->write(("$_[0]/$_[2]." . int ($_ / 10) . ".bfa"));
				}
			} else {
				if (-f "$_[0]/$_[2].bfa") { $tmp2->read("$_[0]/$_[2].bfa",1) }
				$tmp2->remove($_);
				$tmp2->add_data($_,$tmp3);
				if ($SET{'COMPRESS_DO'} ne 'N') {
					&Bforum::_compress("$_[0]/$_[2].bfa",$tmp2->write());
				} else {
					$tmp2->write("$_[0]/$_[2].bfa");
				}
			}
			undef $tmp2;
		}
	}

	$dir++;
	$files += $tmp4;

	closedir (DIR);

	$a_size += (-s "$_[0]/$_[2].bfa");

	if ($in{'d'} && "$_[0]$_[1]" ne "$SET{'USER_DIR'}/$in{'id'}") {
		rmdir("$_[0]$_[1]") || print "\nrmdir $_[0]$_[1] : $!\n";
	}

	return;
}

sub decode {
	my ($buffer);
	if ($ENV{'REQUEST_METHOD'} eq "POST") {
		read(STDIN, $buffer, $ENV{'CONTENT_LENGTH'});
	} else { $buffer = $ENV{'QUERY_STRING'}; }
	if (!$buffer) { $buffer = $ARGV[0]; }
	foreach (@ARGV) {
		if ($_ =~ /^--(\S*)=(\S*)$/) {
			$in{$1} = $2;
		} elsif ($_ =~ /^--(.*)$/) {
			$in{$1} = 1;
		} elsif ($_ =~ /^-(.*)$/) {
			foreach (split(//,$1)) {
				$in{$_} = 1;
			}
		} else {
			$in{'id'} = $_;
		}
	}

	undef @_;
}

sub error {
	print "\nError:" . (caller)[2] . '@' . (caller)[1];
	undef @_;
	exit;
}
